@@ -1,9 +1,9 @@
 
 from django.contrib import admin
-from django.contrib.auth.admin import UserAdmin
 from django.contrib.auth.models import User
 
 from mezzanine.accounts.models import get_profile_model
+from mezzanine.core.admin import SitePermissionUserAdmin
 
 
 Profile = get_profile_model()
@@ -16,8 +16,11 @@ class ProfileInline(admin.StackedInline):
     extra = 0
 
 
-class UserProfileAdmin(UserAdmin):
-    inlines = (ProfileInline,) if Profile else ()
+class UserProfileAdmin(SitePermissionUserAdmin):
+    pass
+
+if Profile:
+    UserProfileAdmin.inlines += (ProfileInline,)
 
 
 admin.site.unregister(User)
