@@ -24,7 +24,9 @@ class LoginForm(Html5Mixin, forms.Form):
         Authenticate the given username/email and password. If the fields
         are valid, store the authenticated user for returning via save().
         """
-        self._user = authenticate(**self.cleaned_data)
+        username = self.cleaned_data.get("username")
+        password = self.cleaned_data.get("password")
+        self._user = authenticate(username=username, password=password)
         if self._user is None:
             raise forms.ValidationError(
                              _("Invalid username/email and password"))
@@ -105,11 +107,13 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         for the user's profile view.
         """
         username = self.cleaned_data.get("username")
-        if username != slugify(username):
+        if username.lower() != slugify(username).lower():
             raise forms.ValidationError(_("Username can only contain letters, "
                                           "numbers, dashes or underscores."))
         try:
-            User.objects.exclude(id=self.instance.id).get(username=username)
+            User.objects.exclude(id=self.instance.id).get(
+                username__iexact=username
+            )
         except User.DoesNotExist:
             return username
         raise forms.ValidationError(_("This username is already registered"))
@@ -157,7 +161,8 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
         # Save profile model.
         if self._has_profile:
             profile = user.get_profile()
-            ProfileFieldsForm(self.data, instance=profile).save()
+            profile_fields_form = self.get_profile_fields_form()
+            profile_fields_form(self.data, instance=profile).save()
 
         if self._signup:
             settings.use_editable()
@@ -169,6 +174,9 @@ class ProfileForm(Html5Mixin, forms.ModelForm):
                                     password=password, is_active=True)
         return user
 
+    def get_profile_fields_form(self):
+        return ProfileFieldsForm
+
 
 class PasswordResetForm(Html5Mixin, forms.Form):
     """
