@@ -70,7 +70,8 @@ class Command(BaseImporterCommand):
             if entry.wp_post_type == "post":
                 post = self.add_post(title=entry.title, content=content,
                                      pub_date=pub_date, tags=terms["tag"],
-                                     categories=terms["category"])
+                                     categories=terms["category"],
+                                     old_url=entry.id)
 
                 # Get the comments from the xml doc.
                 for c in xmlitem.getElementsByTagName("wp:comment"):
