@@ -94,7 +94,8 @@ def blog_post_detail(request, slug, year=None, month=None, day=None,
     ``blog/blog_post_detail_XXX.html`` where ``XXX`` is the blog
     posts's slug.
     """
-    blog_posts = BlogPost.objects.published(for_user=request.user)
+    blog_posts = BlogPost.objects.published(
+                                     for_user=request.user).select_related()
     blog_post = get_object_or_404(blog_posts, slug=slug)
     context = {"blog_post": blog_post, "editable_obj": blog_post}
     templates = [u"blog/blog_post_detail_%s.html" % unicode(slug), template]
