@@ -43,6 +43,15 @@ register_setting(
     default="24x24",
 )
 
+register_setting(
+    name="AKISMET_API_KEY",
+    label=_("Akismet API Key"),
+    description=_("Key for http://akismet.com spam filtering service. Used "
+        "for filtering comments and forms."),
+    editable=True,
+    default="",
+)
+
 register_setting(
     name="CACHE_SET_DELAY_SECONDS",
     description=_("Mezzanine's caching uses a technique know as mint "
@@ -58,15 +67,6 @@ register_setting(
     default=30,
 )
 
-register_setting(
-    name="AKISMET_API_KEY",
-    label=_("Akismet API Key"),
-    description=_("Key for http://akismet.com spam filtering service. Used "
-        "for filtering comments and forms."),
-    editable=True,
-    default="",
-)
-
 if "mezzanine.blog" in settings.INSTALLED_APPS:
     dashboard_tags = (
         ("blog_tags.quick_blog", "mezzanine_tags.app_list"),
@@ -179,6 +179,18 @@ register_setting(
     default=10,
 )
 
+register_setting(
+    name="OWNABLE_MODELS_ALL_EDITABLE",
+    description=_("Models that subclass ``Ownable`` and use the "
+        "``OwnableAdmin`` have their admin change-list records filtered "
+        "down to records owned by the current user. This setting contains a "
+        "sequence of models in the format ``app_label.object_name``, that "
+        "when subclassing ``Ownable``, will still show all records in the "
+        "admin change-list interface, regardless of the current user."),
+    editable=False,
+    default=(),
+)
+
 register_setting(
     name="RICHTEXT_WIDGET_CLASS",
     description=_("Dotted package path and class name of the widget to use "
@@ -270,6 +282,16 @@ register_setting(
     default=RICHTEXT_FILTER_LEVEL_HIGH,
 )
 
+register_setting(
+    name="SEARCH_MODEL_CHOICES",
+    description=_("Sequence of models that will be provided by default as "
+        "choices in the search form. Each model should be in the format "
+        "``app_label.model_name``. Only models that subclass "
+        "``mezzanine.core.models.Displayable`` should be used."),
+    editable=False,
+    default=("pages.Page", "blog.BlogPost"),
+)
+
 register_setting(
     name="SEARCH_PER_PAGE",
     label=_("Search results per page"),
@@ -317,6 +339,19 @@ register_setting(
     default="mezzanine.utils.urls.slugify_unicode",
 )
 
+register_setting(
+    name="SPAM_FILTERS",
+    description=_("Sequence of dotted Python paths to callable functions "
+        "used for checking posted content (such as forms or comments) is "
+        "spam. Each function should accept three arguments: the request "
+        "object, the form object, and the URL that was posted from. "
+        "Defaults to ``mezzanine.utils.views.is_spam_akismet`` which will "
+        "use the http://akismet.com spam filtering service when the "
+        "``AKISMET_API_KEY`` setting is configured."),
+    editable=False,
+    default=("mezzanine.utils.views.is_spam_akismet",),
+)
+
 register_setting(
     name="SSL_ENABLED",
     label=_("Enable SSL"),
@@ -346,6 +381,16 @@ register_setting(
     default=("/admin", "/account"),
 )
 
+register_setting(
+    name="SSL_FORCED_PREFIXES_ONLY",
+    description=_("If ``True``, only URLs specified by the "
+        "``SSL_FORCE_URL_PREFIXES`` setting will be accessible over SSL, "
+        "and all other URLs will be redirected back to HTTP if accessed "
+        "over HTTPS."),
+    editable=False,
+    default=True,
+)
+
 register_setting(
     name="STOP_WORDS",
     description=_("List of words which will be stripped from search queries."),
@@ -443,6 +488,16 @@ register_setting(
     default="mezzanine/js/tinymce_setup.js",
 )
 
+register_setting(
+    name="UPLOAD_TO_HANDLERS",
+    description=_("Dict mapping file field names in the format "
+        "``app_label.model_name.field_name`` to the Python dotted path "
+        "to function names that will be used for the file field's "
+        "``upload_to`` argument."),
+    editable=False,
+    default={},
+)
+
 # The following settings are defined here for documentation purposes
 # as this file is used to auto-generate the documentation for all
 # available settings. They are Mezzanine specific, but their values
