@@ -53,6 +53,7 @@ class RichTextField(models.TextField):
             return value
         tags = settings.RICHTEXT_ALLOWED_TAGS
         attrs = settings.RICHTEXT_ALLOWED_ATTRIBUTES
+        styles = settings.RICHTEXT_ALLOWED_STYLES
         if settings.RICHTEXT_FILTER_LEVEL == RICHTEXT_FILTER_LEVEL_LOW:
             tags += LOW_FILTER_TAGS
             attrs += LOW_FILTER_ATTRS
@@ -62,7 +63,7 @@ class RichTextField(models.TextField):
             return value
         else:
             return clean(value, tags=tags, attributes=attrs, strip=True,
-                         strip_comments=False)
+                         strip_comments=False, styles=styles)
 
 
 class MultiChoiceField(models.CharField):
