@@ -10,9 +10,8 @@ from django.contrib.sites import models as sites_app
 from django.core.management import call_command
 from django.db.models.signals import post_syncdb
 
-from mezzanine.forms.models import Form
-from mezzanine.galleries.models import Gallery
 from mezzanine.pages.models import Page
+
 from mezzanine.pages import models as pages_app
 from mezzanine.utils.tests import copy_test_to_media
 
@@ -31,8 +30,12 @@ def create_user(app, created_models, verbosity, interactive, **kwargs):
 
 
 def create_pages(app, created_models, verbosity, interactive, **kwargs):
+    from mezzanine.forms.models import Form
+    from mezzanine.galleries.models import Gallery
+
     required = set([Page, Form, Gallery])
     if required.issubset(set(created_models)):
+        call_command("loaddata", "mezzanine_required.json")
         if interactive:
             confirm = raw_input("\nWould you like to install some initial "
                                 "content?\nEg: About page, Blog, Contact "
@@ -43,17 +46,7 @@ def create_pages(app, created_models, verbosity, interactive, **kwargs):
                 elif confirm == "no":
                     return
                 confirm = raw_input("Please enter either 'yes' or 'no': ")
-        if verbosity >= 1:
-            print
-            print ("Creating initial content "
-                   "(About page, Blog, Contact form, Gallery) ...")
-            print
-        call_command("loaddata", "mezzanine.json")
-        zip_name = "gallery.zip"
-        copy_test_to_media("mezzanine.core", zip_name)
-        gallery = Gallery.objects.get()
-        gallery.zip_import = zip_name
-        gallery.save()
+            install_optional_data(verbosity)
 
 
 def create_site(app, created_models, verbosity, interactive, **kwargs):
@@ -73,6 +66,22 @@ def create_site(app, created_models, verbosity, interactive, **kwargs):
             print
         Site.objects.create(name="Default", domain=domain)
 
+
+def install_optional_data(verbosity):
+    from mezzanine.galleries.models import Gallery
+
+    call_command("loaddata", "mezzanine_optional.json")
+    zip_name = "gallery.zip"
+    copy_test_to_media("mezzanine.core", zip_name)
+    gallery = Gallery.objects.get()
+    gallery.zip_import = zip_name
+    gallery.save()
+    if verbosity >= 1:
+        print
+        print ("Creating demo content "
+               "(About page, Blog, Contact form, Gallery) ...")
+        print
+
 if not settings.TESTING:
     post_syncdb.connect(create_user, sender=auth_app)
     post_syncdb.connect(create_pages, sender=pages_app)
