@@ -7,19 +7,23 @@ from django.contrib import admin
 from django.contrib.admin.views.decorators import staff_member_required
 from django.contrib.admin.options import ModelAdmin
 from django.contrib.staticfiles import finders
+from django.core.exceptions import PermissionDenied
 from django.core.urlresolvers import reverse
 from django.db.models import get_model
-from django.http import HttpResponse, HttpResponseServerError
+from django.http import (HttpResponse, HttpResponseServerError,
+                         HttpResponseNotFound)
 from django.shortcuts import redirect
 from django.template import RequestContext
 from django.template.loader import get_template
 from django.utils.translation import ugettext_lazy as _
+from django.views.decorators.csrf import requires_csrf_token
 
 from mezzanine.conf import settings
 from mezzanine.core.forms import get_edit_form
-from mezzanine.core.models import Displayable
+from mezzanine.core.models import Displayable, SitePermission
 from mezzanine.utils.cache import add_cache_bypass
 from mezzanine.utils.views import is_editable, paginate, render, set_cookie
+from mezzanine.utils.sites import has_site_permission
 
 
 def set_device(request, device=""):
@@ -40,7 +44,13 @@ def set_site(request):
     site ID is then used in favour of the current request's
     domain in ``mezzanine.core.managers.CurrentSiteManager``.
     """
-    request.session["site_id"] = int(request.GET["site_id"])
+    site_id = int(request.GET["site_id"])
+    if not request.user.is_superuser:
+        try:
+            SitePermission.objects.get(user=request.user, sites=site_id)
+        except SitePermission.DoesNotExist:
+            raise PermissionDenied
+    request.session["site_id"] = site_id
     admin_url = reverse("admin:index")
     next = request.GET.get("next", admin_url)
     # Don't redirect to a change view for an object that won't exist
@@ -74,7 +84,7 @@ def edit(request):
     obj = model.objects.get(id=request.POST["id"])
     form = get_edit_form(obj, request.POST["fields"], data=request.POST,
                          files=request.FILES)
-    if not is_editable(obj, request):
+    if not (is_editable(obj, request) and has_site_permission(request.user)):
         response = _("Permission denied")
     elif form.is_valid():
         form.save()
@@ -89,16 +99,27 @@ def edit(request):
 
 def search(request, template="search_results.html"):
     """
-    Display search results.
+    Display search results. Takes an optional "contenttype" GET parameter
+    in the form "app-name.ModelName" to limit search results to a single model.
     """
     settings.use_editable()
     query = request.GET.get("q", "")
     page = request.GET.get("page", 1)
     per_page = settings.SEARCH_PER_PAGE
     max_paging_links = settings.MAX_PAGING_LINKS
-    results = Displayable.objects.search(query, for_user=request.user)
+    try:
+        search_model = get_model(*request.GET.get("type", "").split(".", 1))
+        if not issubclass(search_model, Displayable):
+            raise TypeError
+    except TypeError:
+        search_model = Displayable
+        search_type = _("Everything")
+    else:
+        search_type = search_model._meta.verbose_name_plural.capitalize()
+    results = search_model.objects.search(query, for_user=request.user)
     paginated = paginate(results, page, per_page, max_paging_links)
-    context = {"query": query, "results": paginated}
+    context = {"query": query, "results": paginated,
+               "search_type": search_type}
     return render(request, template, context)
 
 
@@ -140,7 +161,21 @@ def static_proxy(request):
     return HttpResponse(response, mimetype=mimetype)
 
 
-def server_error(request, template_name='500.html'):
+@requires_csrf_token
+def page_not_found(request, template_name="errors/404.html"):
+    """
+    Mimics Django's 404 handler but with a different template path.
+    """
+    context = RequestContext(request, {
+        "STATIC_URL": settings.STATIC_URL,
+        "request_path": request.path,
+    })
+    t = get_template(template_name)
+    return HttpResponseNotFound(t.render(context))
+
+
+@requires_csrf_token
+def server_error(request, template_name="errors/500.html"):
     """
     Mimics Django's error handler but adds ``STATIC_URL`` to the
     context.
