@@ -1,10 +1,12 @@
 
+from django.core.exceptions import ImproperlyConfigured
 from django import forms
 from django.forms.extras import SelectDateWidget
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import settings
 from mezzanine.core.forms import SplitSelectDateTimeWidget
+from mezzanine.utils.importing import import_dotted_path
 
 
 # Constants for all available field types.
@@ -22,6 +24,7 @@ DATE_TIME = 11
 HIDDEN = 12
 NUMBER = 13
 URL = 14
+DOB = 15
 
 # Names for all available field types.
 NAMES = (
@@ -38,6 +41,7 @@ NAMES = (
     (FILE, _("File upload")),
     (DATE, _("Date")),
     (DATE_TIME, _("Date/time")),
+    (DOB, _("Date of birth")),
     (HIDDEN, _("Hidden")),
 )
 
@@ -54,6 +58,7 @@ CLASSES = {
     FILE: forms.FileField,
     DATE: forms.DateField,
     DATE_TIME: forms.DateTimeField,
+    DOB: forms.DateField,
     HIDDEN: forms.CharField,
     NUMBER: forms.FloatField,
     URL: forms.URLField,
@@ -66,13 +71,14 @@ WIDGETS = {
     RADIO_MULTIPLE: forms.RadioSelect,
     DATE: SelectDateWidget,
     DATE_TIME: SplitSelectDateTimeWidget,
+    DOB: SelectDateWidget,
     HIDDEN: forms.HiddenInput,
 }
 
 # Some helper groupings of field types.
 CHOICES = (CHECKBOX, CHECKBOX_MULTIPLE, SELECT,
            SELECT_MULTIPLE, RADIO_MULTIPLE)
-DATES = (DATE, DATE_TIME)
+DATES = (DATE, DATE_TIME, DOB)
 MULTIPLE = (CHECKBOX_MULTIPLE, SELECT_MULTIPLE)
 
 # HTML5 Widgets
@@ -81,7 +87,19 @@ if settings.FORMS_USE_HTML5:
     WIDGETS.update({
         DATE: html5_field("date", forms.DateInput),
         DATE_TIME: html5_field("datetime", forms.DateTimeInput),
+        DOB: html5_field("date", forms.DateInput),
         EMAIL: html5_field("email", forms.TextInput),
         NUMBER: html5_field("number", forms.TextInput),
         URL: html5_field("url", forms.TextInput),
     })
+
+# Allow extra fields types to be defined via the FORMS_EXTRA_FIELDS
+# setting, which should contain a sequence of three-item sequences,
+# each containing the ID, dotted import path for the field class,
+# and field name, for each custom field type.
+for field_id, field_path, field_name in settings.FORMS_EXTRA_FIELDS:
+    if field_id in CLASSES:
+        err = "ID %s for field %s in FORMS_EXTRA_FIELDS already exists"
+        raise ImproperlyConfigured(err % (field_id, field_name))
+    CLASSES[field_id] = import_dotted_path(field_path)
+    NAMES += ((field_id, _(field_name)),)
