@@ -5,6 +5,7 @@ from django.utils.safestring import mark_safe
 from django.utils.translation import ugettext_lazy as _
 
 from mezzanine.conf import settings
+from mezzanine.core.forms import Html5Mixin
 from mezzanine.generic.models import Keyword, ThreadedComment, RATING_RANGE
 
 
@@ -73,7 +74,7 @@ class KeywordsWidget(forms.MultiWidget):
         return data.get("%s_0" % name, "")
 
 
-class ThreadedCommentForm(CommentForm):
+class ThreadedCommentForm(CommentForm, Html5Mixin):
 
     name = forms.CharField(label=_("Name"), help_text=_("required"),
                            max_length=50)
@@ -87,6 +88,11 @@ class ThreadedCommentForm(CommentForm):
     cookie_prefix = "mezzanine-comment-"
 
     def __init__(self, request, *args, **kwargs):
+        """
+        Set some initial field values from cookies or the logged in
+        user, and apply some HTML5 attributes to the fields if the
+        ``FORMS_USE_HTML5`` setting is ``True``.
+        """
         kwargs.setdefault("initial", {})
         user = request.user
         for field in ThreadedCommentForm.cookie_fields:
@@ -94,7 +100,9 @@ class ThreadedCommentForm(CommentForm):
             value = request.COOKIES.get(cookie_name, "")
             if not value and user.is_authenticated():
                 if field == "name":
-                    value = user.get_full_name() or user.username
+                    value = user.get_full_name()
+                    if not value and user.username != user.email:
+                        value = user.username
                 elif field == "email":
                     value = user.email
             kwargs["initial"][field] = value
