@@ -32,16 +32,16 @@ def send_mail_template(subject, template, addr_from, addr_to, context=None,
     msg.send(fail_silently=fail_silently)
 
 
-def send_verification_mail(request, user, verifcation_type):
+def send_verification_mail(request, user, verification_type):
     """
     Sends an email with a verification link to users when
     ``ACCOUNTS_VERIFICATION_REQUIRED`` is ```True`` and they're signing
     up, or when they retrieve a lost password.
-    The ``verifcation_type`` arg is both the name of the urlpattern for
+    The ``verification_type`` arg is both the name of the urlpattern for
     the verification link, as well as the names of the email templates
     to use.
     """
-    verify_url = reverse(verifcation_type, kwargs={
+    verify_url = reverse(verification_type, kwargs={
         "uidb36": int_to_base36(user.id),
         "token": default_token_generator.make_token(user),
     }) + "?next=" + request.GET.get("next", "/")
@@ -50,9 +50,9 @@ def send_verification_mail(request, user, verifcation_type):
         "user": user,
         "verify_url": verify_url,
     }
-    subject_template = "email/%s_subject.txt" % verifcation_type
+    subject_template = "email/%s_subject.txt" % verification_type
     subject = loader.get_template(subject_template).render(Context(context))
     send_mail_template("".join(subject.splitlines()),
-                       "email/%s" % verifcation_type,
+                       "email/%s" % verification_type,
                        settings.DEFAULT_FROM_EMAIL, user.email,
                        context=context, fail_silently=settings.DEBUG)
