@@ -1,5 +1,6 @@
 
 from datetime import datetime, timedelta
+
 from urllib import urlencode
 from urllib2 import Request, urlopen
 
@@ -12,26 +13,32 @@ from django.utils.translation import ugettext as _
 
 import mezzanine
 from mezzanine.conf import settings
+from mezzanine.utils.sites import has_site_permission
+from mezzanine.utils.importing import import_dotted_path
 
 
 def is_editable(obj, request):
     """
-    Returns ``True`` if the object is editable for the request. First check
-    for a custom ``editable`` handler on the object, otherwise use the logged
-    in user and check change permissions for the object's model.
+    Returns ``True`` if the object is editable for the request. First
+    check for a custom ``editable`` handler on the object, otherwise
+    use the logged in user and check change permissions for the
+    object's model.
     """
     if hasattr(obj, "is_editable"):
         return obj.is_editable(request)
     else:
         perm = obj._meta.app_label + "." + obj._meta.get_change_permission()
-        return request.user.is_authenticated() and request.user.has_perm(perm)
+        return (request.user.is_authenticated() and
+                has_site_permission(request.user) and
+                request.user.has_perm(perm))
 
 
-def is_spam(request, form, url):
+def is_spam_akismet(request, form, url):
     """
     Identifies form data as being spam, using the http://akismet.com
     service. The Akismet API key should be specified in the
-    ``AKISMET_API_KEY`` setting.
+    ``AKISMET_API_KEY`` setting. This function is the default spam
+    handler defined in the ``SPAM_FILTERS`` setting.
 
     The name, email, url and comment fields are all guessed from the
     form fields:
@@ -86,6 +93,18 @@ def is_spam(request, form, url):
     return response == "true"
 
 
+def is_spam(request, form, url):
+    """
+    Main entry point for spam handling - called from the comment view and
+    page processor for ``mezzanine.forms``, to check if posted content is
+    spam. Spam filters are configured via the ``SPAM_FILTERS`` setting.
+    """
+    for spam_filter_path in settings.SPAM_FILTERS:
+        spam_filter = import_dotted_path(spam_filter_path)
+        if spam_filter(request, form, url):
+            return True
+
+
 def paginate(objects, page_num, per_page, max_paging_links):
     """
     Return a paginated page for the given objects, giving it a custom
